# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-26 06:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0047_auto_20191226_1354'),
    ]

    operations = [
        migrations.AddField(
            model_name='bargainreward',
            name='bargain_high',
            field=models.FloatField(blank=True, null=True, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\x9c\x80\xe9\xab\x98\xe5\x80\xbc'),
        ),
        migrations.AddField(
            model_name='bargainreward',
            name='bargain_low',
            field=models.FloatField(blank=True, null=True, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\x9c\x80\xe4\xbd\x8e\xe5\x80\xbc'),
        ),
    ]
