# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-26 05:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0046_auto_20191225_1736'),
    ]

    operations = [
        migrations.AddField(
            model_name='bargainreward',
            name='end_money',
            field=models.FloatField(blank=True, null=True, verbose_name=b'\xe5\xae\x8c\xe6\x88\x90\xe9\x87\x91\xe9\xa2\x9d'),
        ),
        migrations.AddField(
            model_name='bargainreward',
            name='end_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name=b'\xe6\xb4\xbb\xe5\x8a\xa8\xe7\xbb\x93\xe6\x9d\x9f\xe6\x97\xb6\xe9\x97\xb4'),
        ),
        migrations.AddField(
            model_name='bargainreward',
            name='max_bargain',
            field=models.IntegerField(default=1, verbose_name=b'\xe6\x9c\x80\xe5\xa4\xa7\xe7\xa0\x8d\xe4\xbb\xb7\xe6\xac\xa1\xe6\x95\xb0'),
        ),
        migrations.AddField(
            model_name='bargainreward',
            name='start_money',
            field=models.FloatField(blank=True, null=True, verbose_name=b'\xe8\xb5\xb7\xe5\xa7\x8b\xe9\x87\x91\xe9\xa2\x9d'),
        ),
        migrations.AddField(
            model_name='bargainreward',
            name='start_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name=b'\xe6\xb4\xbb\xe5\x8a\xa8\xe5\xbc\x80\xe5\xa7\x8b\xe6\x97\xb6\xe9\x97\xb4'),
        ),
    ]
