# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-26 10:09
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0048_auto_20191226_1413'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='bind_preuser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_crm.PreUser', verbose_name=b'\xe7\xba\xa2\xe5\x8c\x85\xe5\x8f\x91\xe6\x94\xbe\xe6\x96\xb0peruser\xe8\xb4\xa6\xe5\x8f\xb7'),
        ),
    ]
